|Build Status|

Google Cloud Platform Resource Provider
=======================================

The Google Cloud Platform (GCP) resource provider for Pulumi lets you
use GCP resources in your cloud programs. To use this package, please
`install the Pulumi CLI first <https://pulumi.io/>`__.

Installing
----------

This package is available in many languages in the standard packaging
formats.

Node.js (Java/TypeScript)
~~~~~~~~~~~~~~~~~~~~~~~~~

To use from JavaScript or TypeScript in Node.js, install using either
``npm``:

::

   $ npm install @pulumi/gcp

or ``yarn``:

::

   $ yarn add @pulumi/gcp

Python
~~~~~~

To use from Python, install using ``pip``:

::

   $ pip install pulumi_gcp

Go
~~

To use from Go, use ``go get`` to grab the latest version of the library

::

   $ go get github.com/pulumi/pulumi-gcp/sdk/go/...

Configuring credentials
-----------------------

There are a variety of ways credentials may be configured for the GCP
provider, appropriate for different use cases. They are enumerated `in
the quickstart guide <https://pulumi.io/quickstart/gcp/setup/>`__.

Reference
---------

For detailed reference documentation, please visit `the API
docs <https://pulumi.io/reference/pkg/nodejs/@pulumi/gcp/index.html>`__.

.. |Build Status| image:: https://travis-ci.com/pulumi/pulumi-gcp.svg?token=eHg7Zp5zdDDJfTjY8ejq&branch=master
   :target: https://travis-ci.com/pulumi/pulumi-gcp
